==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BodyInElementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodyInElement;
import io.ciera.tool.sql.ooaofooa.body.BodyInElementSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.List;


public class BodyInElementSetImpl extends InstanceSet<BodyInElementSet,BodyInElement> implements BodyInElementSet {

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( BodyInElement bodyinelement : this ) bodyinelement.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setElement_ID( UniqueId ref_Element_ID ) throws XtumlException {
        for ( BodyInElement bodyinelement : this ) bodyinelement.setElement_ID( ref_Element_ID );
    }


    // selections
    @Override
    public BodySet R640_has_declared_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( BodyInElement bodyinelement : this ) bodyset.add( bodyinelement.R640_has_declared_Body() );
        return bodyset;
    }
    @Override
    public PackageableElementSet R640_is_declared_in_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( BodyInElement bodyinelement : this ) packageableelementset.add( bodyinelement.R640_is_declared_in_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public BodyInElement nullElement() {
        return BodyInElementImpl.EMPTY_BODYINELEMENT;
    }

    @Override
    public BodyInElementSet emptySet() {
      return new BodyInElementSetImpl();
    }

    @Override
    public BodyInElementSet value() {
        return this;
    }

    @Override
    public List<BodyInElement> elements() {
        return Arrays.asList(toArray(new BodyInElement[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BodyInElementSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodyInElement;
import io.ciera.tool.sql.ooaofooa.body.BodyInElementSet;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BodyInElementSetImpl extends InstanceSet<BodyInElementSet,BodyInElement> implements BodyInElementSet {

    public BodyInElementSetImpl() {
    }

    public BodyInElementSetImpl(Comparator<? super BodyInElement> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( BodyInElement bodyinelement : this ) bodyinelement.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setElement_ID( UniqueId ref_Element_ID ) throws XtumlException {
        for ( BodyInElement bodyinelement : this ) bodyinelement.setElement_ID( ref_Element_ID );
    }


    // selections
    @Override
    public BodySet R640_has_declared_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( BodyInElement bodyinelement : this ) bodyset.add( bodyinelement.R640_has_declared_Body() );
        return bodyset;
    }
    @Override
    public PackageableElementSet R640_is_declared_in_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( BodyInElement bodyinelement : this ) packageableelementset.add( bodyinelement.R640_is_declared_in_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public BodyInElement nullElement() {
        return BodyInElementImpl.EMPTY_BODYINELEMENT;
    }

    @Override
    public BodyInElementSet emptySet() {
      return new BodyInElementSetImpl();
    }

    @Override
    public BodyInElementSet emptySet(Comparator<? super BodyInElement> comp) {
      return new BodyInElementSetImpl(comp);
    }

    @Override
    public BodyInElementSet value() {
        return this;
    }

    @Override
    public List<BodyInElement> elements() {
        return Arrays.asList(toArray(new BodyInElement[0]));
    }

}
